@@ -17,17 +17,56 @@ import signal
 import socket
 import subprocess
 import sys
-from argparse import ArgumentParser, ArgumentError, SUPPRESS
+from argparse import SUPPRESS, ArgumentError, ArgumentParser
 from datetime import datetime, timedelta
-from queue import Queue, Empty
+from queue import Empty, Queue
+from threading import Event, Thread, get_native_id
 from time import sleep
 from timeit import default_timer as timer
-from typing import List, Tuple, Dict, Any
-from threading import Thread, Event, get_native_id
+from typing import Any, Dict, List, Tuple, cast
 
-from zeroconf import ServiceInfo, Zeroconf, ServiceBrowser, ServiceStateChange
+from zeroconf import ServiceBrowser, ServiceInfo, ServiceStateChange, Zeroconf
 
+from ..comm.comm_buffer import CommBuffer, CommBufferSingleton
+from ..comm.command_listener import CommandDispatcher, CommandListener
+from ..comm.enqueue_proxy_requests import EnqueueProxyRequests
+from ..db.client_state_listener import ClientStateListener
+from ..db.component_state import ComponentState
+from ..db.component_state_store import ComponentStateStore
+from ..db.engine_state import EngineState
+from ..db.prod_info import ProdInfo
+from ..db.startup_state import StartupState
+from ..gpio.gpio_handler import GpioHandler
+from ..pdi.amc2_req import Amc2Req, Direction
+from ..pdi.asc2_req import Asc2Req
+from ..pdi.base_req import BaseReq
+from ..pdi.constants import PDI_SOP, Asc2Action, D4Action, PdiCommand
+from ..pdi.d4_req import D4Req
+from ..pdi.pdi_listener import PdiListener
+from ..pdi.pdi_req import AllReq, PdiReq
+from ..pdi.pdi_state_store import PdiStateStore
+from ..protocol.command_def import CommandDefEnum
+from ..protocol.command_req import CommandReq
+from ..protocol.constants import (
+    BROADCAST_TOPIC,
+    DEFAULT_BASE_PORT,
+    DEFAULT_BAUDRATE,
+    DEFAULT_PORT,
+    DEFAULT_QUEUE_SIZE,
+    DEFAULT_SERVER_PORT,
+    DEFAULT_VALID_BAUDRATES,
+    PROGRAM_NAME,
+    SERVICE_NAME,
+    SERVICE_TYPE,
+    CommandScope,
+    Mixins,
+)
+from ..protocol.tmcc1.tmcc1_constants import TMCC1SyncCommandEnum
+from ..utils.argument_parser import PyTrainArgumentParser, StripPrefixesHelpFormatter
+from ..utils.dual_logging import set_up_logging
+from ..utils.ip_tools import find_base_address, get_ip_address
 from .acc import AccCli
+from .amc2 import Amc2Cli
 from .asc2 import Asc2Cli
 from .bpc2 import Bpc2Cli
 from .dialogs import DialogsCli
@@ -38,43 +77,6 @@ from .lighting import LightingCli
 from .route import RouteCli
 from .sounds import SoundEffectsCli
 from .switch import SwitchCli
-from ..comm.comm_buffer import CommBuffer, CommBufferSingleton
-from ..comm.command_listener import CommandListener, CommandDispatcher
-from ..comm.enqueue_proxy_requests import EnqueueProxyRequests
-from ..db.client_state_listener import ClientStateListener
-from ..db.component_state import ComponentState
-from ..db.engine_state import EngineState
-from ..db.component_state_store import ComponentStateStore
-from ..db.prod_info import ProdInfo
-from ..db.startup_state import StartupState
-from ..gpio.gpio_handler import GpioHandler
-from ..pdi.asc2_req import Asc2Req
-from ..pdi.d4_req import D4Req
-from ..pdi.base_req import BaseReq
-from ..pdi.constants import PdiCommand, PDI_SOP, D4Action, Asc2Action
-from ..pdi.pdi_listener import PdiListener
-from ..pdi.pdi_req import PdiReq, AllReq
-from ..pdi.pdi_state_store import PdiStateStore
-from ..protocol.command_def import CommandDefEnum
-from ..protocol.command_req import CommandReq
-from ..protocol.constants import (
-    BROADCAST_TOPIC,
-    CommandScope,
-    DEFAULT_BASE_PORT,
-    PROGRAM_NAME,
-    SERVICE_TYPE,
-    SERVICE_NAME,
-    DEFAULT_SERVER_PORT,
-    DEFAULT_VALID_BAUDRATES,
-    DEFAULT_BAUDRATE,
-    DEFAULT_PORT,
-    DEFAULT_QUEUE_SIZE,
-    Mixins,
-)
-from ..protocol.tmcc1.tmcc1_constants import TMCC1SyncCommandEnum
-from ..utils.argument_parser import StripPrefixesHelpFormatter, PyTrainArgumentParser
-from ..utils.dual_logging import set_up_logging
-from ..utils.ip_tools import get_ip_address, find_base_address
 
 DEFAULT_BUTTONS_FILE: str = "buttons.py"
 DEFAULT_REPLAY_FILE: str = "replay.txt"
@@ -97,9 +99,9 @@ class PyTrain:
         from .. import get_version
 
         if cmd_line:
-            args = self.command_line_parser().parse_args(cmd_line)
+            args = self.command_line_parser_ex().parse_args(cmd_line)
         else:
-            args = self.command_line_parser().parse_args()
+            args = self.command_line_parser_ex().parse_args()
         log.debug(f"{PROGRAM_NAME} args: {args}")
         self._args = args
         self._buttons_file = args.buttons_file
@@ -304,7 +306,7 @@ class PyTrain:
 
             # Load client state. Must be done before button file is processed
             if self.is_client:
-                if self._tmcc_listener.update_client_if_needed() is True:
+                if self._tmcc_listener.update_client_if_needed():
                     self(CommandReq(TMCC1SyncCommandEnum.UPDATE))
                 else:
                     self._load_client_state()
@@ -362,6 +364,8 @@ class PyTrain:
             if self._headless is False and self._api is False:
                 readline.write_history_file(DEFAULT_HISTORY_FILE)
             self.shutdown_service()
+            # print closing line
+            log.info(f"{PROGRAM_NAME} exiting...")
             if self._admin_action in ACTION_TO_ADMIN_COMMAND_MAP:
                 if self._admin_action == TMCC1SyncCommandEnum.UPGRADE:
                     self.upgrade()
@@ -401,9 +405,33 @@ class PyTrain:
     def tmcc_buffer(self) -> CommBuffer:
         return self._tmcc_buffer
 
+    def command_line_parser_ex(self) -> ArgumentParser:
+        from .. import is_package
+
+        parser = PyTrainArgumentParser(add_help=False)
+        parser.add_argument(
+            "-version",
+            action="version",
+            version=self.version,
+            help="Show version and exit",
+        )
+
+        ptp = cast(PyTrainArgumentParser, self.command_line_parser())
+        ptp.remove_args(["-version"])
+        prog = "pytrain" if is_package() else "pytrain.py"
+        return PyTrainArgumentParser(
+            prog=prog,
+            add_help=False,
+            description="Send TMCC and Legacy-formatted commands to a Lionel Base 3 and/or LCS Ser2",
+            parents=[
+                parser,
+                ptp,
+            ],
+        )
+
     @classmethod
     def command_line_parser(cls) -> ArgumentParser:
-        from .. import is_package, get_version
+        from .. import get_version, is_package
 
         prog = "pytrain" if is_package() else "pytrain.py"
         parser = PyTrainArgumentParser(
@@ -480,6 +508,28 @@ class PyTrain:
         )
         return parser
 
+    @property
+    def version(self) -> str:
+        """
+        Return version string. If running, also show client/server status,
+        server version, and server IP
+        """
+        from .. import get_version
+
+        try:
+            ver = f"{PROGRAM_NAME} {self._version} {'Client' if self.is_client else 'Server'}"
+            if self.is_client is True and self._server:
+                s_ver = self._tmcc_buffer.server_version
+                ver += f"; Server v{'.'.join([str(x) for x in s_ver])} @{self._server}"
+            if self._tmcc_buffer.base3_address:
+                ver += f"; Base 3 @{self._tmcc_buffer.base3_address}"
+            return ver
+        except AttributeError:
+            pass
+
+        ver = f"{self.__class__.__qualname__} {get_version()}"
+        return ver
+
     def __call__(self, cmd: CommandReq | PdiReq) -> None:
         """
         Callback specified in the Subscriber protocol used to send events to listeners
@@ -620,7 +670,7 @@ class PyTrain:
         raise KeyboardInterrupt()
 
     @staticmethod
-    def decode_command(param: List[str]) -> None:
+    def decode_command(param: List[str]) -> tuple[bytes, CommandReq | PdiReq | None]:
         try:
             param = "".join(param).lower().strip()
             if param.startswith("0x"):
@@ -632,11 +682,18 @@ class PyTrain:
             else:
                 cmd = CommandReq.from_bytes(byte_str)
             print(f"0x{byte_str.hex()} --> {cmd}")
+            return byte_str, cmd
         except Exception as e:
             log.info(e)
+        return bytes(), None
+
+    def send_command(self, param: List[str]) -> None:
+        byte_str, cmd = self.decode_command(param)
+        if cmd:
+            cmd.send()
 
     def reboot(self, reboot: bool = True) -> None:
-        if reboot is True:
+        if reboot:
             msg = "rebooting"
         else:
             msg = "shutting down"
@@ -645,7 +702,7 @@ class PyTrain:
         if self.is_api:
             self._exit_status = PyTrainExitStatus.REBOOT if reboot is True else PyTrainExitStatus.SHUTDOWN
             raise PyTrainExitException(PyTrainExitStatus.REBOOT if reboot is True else PyTrainExitStatus.SHUTDOWN)
-        if reboot is True:
+        if reboot:
             opt = " -r"
         else:
             opt = ""
@@ -659,7 +716,7 @@ class PyTrain:
         self.relaunch(PyTrainExitStatus.RESTART)
 
     def update(self, do_inform: bool = True) -> None:
-        from .. import is_package, PROGRAM_PACKAGE
+        from .. import PROGRAM_PACKAGE, is_package
 
         if do_inform:
             log.info(f"{'Server' if self.is_server else 'Client'} updating...")
@@ -701,7 +758,7 @@ class PyTrain:
             self._exit_status = exit_status
             raise PyTrainExitException(exit_status)
         # are we a service or run from the commandline?
-        if self.is_service is True:
+        if self.is_service:
             # restart service
             os.system(f"sudo systemctl restart pytrain_{'server' if self.is_server else 'client'}.service")
         else:
@@ -716,7 +773,7 @@ class PyTrain:
     def is_service(self) -> bool:
         from .. import is_linux
 
-        if is_linux() is False:
+        if not is_linux():
             return False
         service = f"pytrain_{'server' if self.is_server else 'client'}.service"
         stat = subprocess.call(f"systemctl is-active --quiet {service}".split())
@@ -787,7 +844,7 @@ class PyTrain:
             while waiting > 0:
                 print(f"Looking for {PROGRAM_NAME} servers {cursor[waiting % 4]}", end="\r")
                 waiting -= 1
-                if self._server_discovered.wait(0.5) is True:
+                if self._server_discovered.wait(0.5):
                     for info in self._pytrain_servers:
                         is_ser2 = False
                         is_base3 = False
@@ -799,7 +856,7 @@ class PyTrain:
                                 is_ser2 = decoded_value == "1"
                             elif decoded_prop == "Base3":
                                 is_base3 = decoded_value == "1"
-                        if is_base3 is True:
+                        if is_base3:
                             base3_info = info
                         if is_ser2 is True and is_base3 is True:
                             waiting = 0
@@ -909,6 +966,9 @@ class PyTrain:
                     if parse_only is False and args.command == "decode":
                         self.decode_command(ui_parts[1:])
                         return None
+                    if parse_only is False and args.command == "send":
+                        self.send_command(ui_parts[1:])
+                        return None
                     if parse_only is False and args.command == "pdi":
                         try:
                             self._do_pdi(ui_parts[1:])
@@ -922,7 +982,7 @@ class PyTrain:
                         print(timedelta(seconds=timer() - self._started_at))
                         return None
                     if parse_only is False and args.command == "version":
-                        print(f"{PROGRAM_NAME} {self._version} {'Client' if self.is_client else 'Server'}")
+                        print(self.version)
                         return None
                     #
                     # we're done with the admin/special commands, now do train stuff
@@ -942,7 +1002,7 @@ class PyTrain:
                                     break
                             else:
                                 break  # we're into a subparser
-                        if has_train_arg is False:
+                        if not has_train_arg:
                             ui_parts.insert(2, "-train")
                     if parse_only is True and isinstance(ui_parser, PyTrainArgumentParser):
                         # TODO: provide tool to get usage text
@@ -954,7 +1014,7 @@ class PyTrain:
                         return cli_cmd.command.command_req
                     cli_cmd.send()
                 except ArgumentError as e:
-                    if parse_only is True:
+                    if parse_only:
                         return e.message
                     log.warning(e)
                 finally:
@@ -1106,9 +1166,9 @@ class PyTrain:
             elif param[0].lower().startswith("r"):
                 agr = BaseReq(int(param[1]), PdiCommand.BASE_ROUTE)
         elif param_len >= 3:
-            from ..pdi.pdi_device import PdiDevice
-            from ..pdi.constants import CommonAction, IrdaAction
+            from ..pdi.constants import Amc2Action, CommonAction, IrdaAction
             from ..pdi.irda_req import IrdaReq, IrdaSequence
+            from ..pdi.pdi_device import PdiDevice
 
             dev = PdiDevice.by_prefix(param[0])
             if dev is None:
@@ -1150,6 +1210,25 @@ class PyTrain:
                 if param_len > 3:
                     data = int(param[3])
                 agr = Asc2Req(tmcc_id, PdiCommand.ASC2_SET, ca, values=data)
+            elif ca in {Amc2Action.MOTOR, Amc2Action.LAMP}:
+                if param_len >= 4:
+                    device = int(param[3])
+                    if param_len == 4:
+                        if ca == Amc2Action.MOTOR:
+                            agr = Amc2Req(tmcc_id, PdiCommand.AMC2_GET, ca, motor=device)
+                        else:
+                            agr = Amc2Req(tmcc_id, PdiCommand.AMC2_GET, ca, lamp=device)
+                    elif param_len == 5 and ca == Amc2Action.LAMP:
+                        level = int(param[4])
+                        agr = Amc2Req(tmcc_id, PdiCommand.AMC2_SET, ca, lamp=device, level=level)
+                    elif param_len == 6 and ca == Amc2Action.MOTOR:
+                        speed = int(param[4])
+                        dr = Direction.by_prefix(param[5])
+                        agr = Amc2Req(tmcc_id, PdiCommand.AMC2_SET, ca, motor=device, speed=speed, direction=dr)
+                    else:
+                        raise AttributeError(f"Invalid parameter count for AMC2 {ca.label}")
+                else:
+                    raise AttributeError(f"Must specify motor/lamp value for {ca.label}")
             elif ca is not None:
                 agr = dev.build_req(tmcc_id, ca)
         else:
@@ -1180,6 +1259,7 @@ class PyTrain:
             "-accessory", action="store_const", const=AccCli, dest="command", help="Issue accessory commands"
         )
         group.add_argument("-asc2", action="store_const", const=Asc2Cli, dest="command", help="Issue Asc2 commands")
+        group.add_argument("-amc2", action="store_const", const=Amc2Cli, dest="command", help="Issue Amc2 commands")
         group.add_argument("-bpc2", action="store_const", const=Bpc2Cli, dest="command", help="Issue Bpc2 commands")
         group.add_argument(
             "-db", action="store_const", const="db", dest="command", help="Query engine/train/switch/accessory state"
@@ -1243,6 +1323,9 @@ class PyTrain:
             help=f"Reload {PROGRAM_NAME} state from Lionel Base 3",
         )
         group.add_argument("-route", action="store_const", const=RouteCli, dest="command", help="Fire defined routes")
+        group.add_argument(
+            "-send", action="store_const", const="send", dest="command", help="Send TMCC/PDI command bytes"
+        )
         group.add_argument(
             "-shutdown",
             action="store_const",
