@@ -11,14 +11,13 @@ from __future__ import annotations
 
 import logging
 from abc import ABC, ABCMeta, abstractmethod
-from typing import Any, TypeVar, Generic, Callable
+from typing import Any, Callable, Generic, TypeVar
 
 from ..pdi.base3_component import ConsistComponent, RouteComponent
 from ..pdi.pdi_req import PdiReq
-
 from ..protocol.command_req import CommandReq
+from ..protocol.constants import LEGACY_CONTROL_TYPE, CommandScope
 from ..protocol.multibyte.multibyte_constants import TMCC2EffectsControl
-from ..protocol.constants import CommandScope, LEGACY_CONTROL_TYPE
 from ..protocol.tmcc1.tmcc1_constants import TMCC1EngineCommandEnum
 from ..utils.text_utils import title
 
@@ -333,7 +332,7 @@ class CompData(ABC, Generic[R]):
 
     @classmethod
     def rpm_labor_to_pkg(cls, rpm: int, labor: int) -> UpdatePkg:
-        return UpdatePkg("rpm_labor", 0xC0, 1, default_to_func(cls.encode_rpm_labor(rpm, labor)))
+        return UpdatePkg("rpm_labor", 0x0C, 1, default_to_func(cls.encode_rpm_labor(rpm, labor)))
 
     # noinspection PyTypeChecker
     @classmethod
@@ -389,7 +388,7 @@ class CompData(ABC, Generic[R]):
                                     labor = req.data
                             base_value = conv_tpl[1](rpm, labor)
                         elif sub_field == "smoke":
-                            if cmd.is_tmcc1 is True:
+                            if cmd.is_tmcc1:
                                 base_value = conv_tpl[1](TMCC1_TO_BASE_SMOKE_MAP, req.data)
                             else:
                                 base_value = conv_tpl[1](TMCC1_TO_BASE_SMOKE_MAP, req.data)
@@ -406,7 +405,7 @@ class CompData(ABC, Generic[R]):
         return update_pkgs
 
     @abstractmethod
-    def __init__(self, data: bytes, scope: CommandScope, tmcc_id: int = None) -> None:
+    def __init__(self, data: bytes | None, scope: CommandScope, tmcc_id: int = None) -> None:
         super().__init__()
         self._tmcc_id: int | None = tmcc_id
         self._scope = scope
@@ -445,7 +444,7 @@ class CompData(ABC, Generic[R]):
                 name = "rpm_labor"
             value = self.__dict__["_" + name]
             if name == "smoke" and isinstance(self, EngineData):
-                if self.is_legacy is True:
+                if self.is_legacy:
                     map_dict = BASE_TO_TMCC2_SMOKE_MAP
                     default = TMCC2EffectsControl.SMOKE_OFF
                 else:
@@ -501,7 +500,7 @@ class CompData(ABC, Generic[R]):
         if self.tmcc_id <= 99:
             # delete any entries that are 4-digit specific
             for k in list(schema.keys()):
-                if schema[k].is_d4_only is True:
+                if schema[k].is_d4_only:
                     del schema[k]
         byte_str = bytes()
         last_idx = 0
@@ -526,7 +525,7 @@ class CompData(ABC, Generic[R]):
             print(f"TMCC_ID: {self.tmcc_id} Scope: {self.scope}")
         data_len = len(data)
         for k, v in pmap.items():
-            if isinstance(v, CompDataHandler) is False:
+            if not isinstance(v, CompDataHandler):
                 continue
             item_len = v.length
             if data_len >= ((k + item_len) - 1) and hasattr(self, v.field) and getattr(self, v.field) is None:
@@ -542,7 +541,7 @@ class CompData(ABC, Generic[R]):
 class EngineData(CompData):
     def __init__(
         self,
-        data: bytes,
+        data: bytes | None,
         tmcc_id: int = None,
         scope: CommandScope = CommandScope.ENGINE,
     ) -> None:
@@ -602,7 +601,7 @@ class TrainData(EngineData):
             components are defined.
     """
 
-    def __init__(self, data: bytes, tmcc_id: int = None) -> None:
+    def __init__(self, data: bytes | None, tmcc_id: int = None) -> None:
         self._signal_initializing()
         self._consist_flags: int | None = None
         self._consist_comps: list[ConsistComponent] | None = None
@@ -679,10 +678,21 @@ class CompDataMixin(Generic[C]):
 
     @property
     def is_comp_data_record(self) -> bool:
-        return self.comp_data and self._comp_data_record is True
+        return self._comp_data is not None and self._comp_data_record is True
 
     def initialize(self, scope: CommandScope, tmcc_id: int) -> None:
         data_len = PdiReq.scope_record_length(scope)
         if scope == CommandScope.SWITCH:
             # noinspection PyTypeChecker
             self._comp_data = SwitchData(b"\xff" * data_len, tmcc_id)
+        elif scope == CommandScope.ENGINE:
+            self._comp_data = EngineData(b"\xff" * data_len, tmcc_id)
+        elif scope == CommandScope.TRAIN:
+            self._comp_data = TrainData(b"\xff" * data_len, tmcc_id)
+        elif scope == CommandScope.ROUTE:
+            self._comp_data = RouteData(b"\xff" * data_len, tmcc_id)
+        elif scope == CommandScope.ACC:
+            self._comp_data = AccessoryData(b"\xff" * data_len, tmcc_id)
+        else:
+            raise NotImplementedError(f"Unknown scope {scope.name}")
+        self._comp_data_record = True
