@@ -824,14 +824,9 @@ class GpioHandler:
         prefix: CommandReq,
         command: CommandReq,
     ) -> Callable:
-        tmcc_command_buffer = CommBuffer.build()
-
         def func() -> None:
-            nonlocal tmcc_command_buffer
-
-            byte_str = bytes()
-            byte_str += prefix.as_bytes * 2
-            byte_str += command.as_bytes
-            tmcc_command_buffer.enqueue_command(byte_str)
+            if prefix:
+                prefix.send(repeat=2)
+            command.send()
 
         return func
