@@ -115,6 +115,8 @@ class LaunchGui(Thread):
             self._monitored_state = self._state_store.get_state(CommandScope.ENGINE, self.tmcc_id, False)
             if self._monitored_state is None:
                 raise ValueError(f"No state found for tmcc_id: {self.tmcc_id}")
+            # watch for external state changes
+            StateWatcher(self._monitored_state, self.sync_gui_state)
             # start GUI
             self.start()
             # listen for state updates
@@ -136,21 +138,17 @@ class LaunchGui(Thread):
                 # power on?
                 if self._monitored_state.is_started is True:
                     self.do_power_on()
-                    self.lights_on_req.send(delay=0.5)
-                    self.do_lights_on()
                 else:
-                    self.lights_off_req.send()
                     self.do_power_off()
-                    self.do_lights_off()
                 # lights on?
                 self.sync_pad_lights()
 
     def sync_pad_lights(self):
         with self._cv:
             if self._monitored_state.is_aux2 is True:
-                self.do_lights_off()
-            else:
                 self.do_lights_on()
+            else:
+                self.do_lights_off()
 
     def __call__(self, cmd: CommandReq) -> None:
         with self._cv:
@@ -183,6 +181,9 @@ class LaunchGui(Thread):
                         self.do_klaxon_off()
                         if self._is_countdown:
                             self.do_abort(detected=True)
+                        else:
+                            # reset causes engine to start up, check for that state change here
+                            self.sync_gui_state()
                 elif self.is_active():
                     if cmd.command == TMCC1EngineCommandEnum.REAR_COUPLER:
                         self.do_power_on()
